pub struct Style {
pub line_height: LineHeight,
pub text_size: Option<Pixels>,
pub padding: Padding,
pub background_color: Color,
pub foreground_color: Color,
pub font: Font,
pub cursor_shape: CursorShape,
pub palette: Arc<Palette256>,
}Fields
line_height: LineHeighttext_size: Option<Pixels>padding: Paddingbackground_color: Colorforeground_color: Colorfont: Fontcursor_shape: CursorShapepalette: Arc<Palette256>This value is used to set the height of the background for the text. If you use a custom font, you might have to experiment which value works best for your font.
Implementations
Sourceimpl Style
impl Style
pub fn line_height(self, line_height: impl Into<LineHeight>) -> Self
pub fn text_size(self, size: impl Into<Pixels>) -> Self
pub fn padding(self, padding: Padding) -> Self
pub fn foreground_color(self, color: impl Into<Color>) -> Self
pub fn background_color(self, color: impl Into<Color>) -> Self
pub fn font(self, font: Font) -> Self
pub fn palette(self, palette: Arc<Palette256>) -> Self
pub fn cursor_shape(self, shape: CursorShape) -> Self