pub struct Terminal { /* private fields */ }Implementations
Sourceimpl Terminal
impl Terminal
pub fn new() -> (Self, Task<Message>)
pub fn id(self, id: impl Into<Id>) -> Self
pub fn style(self, style: Style) -> Self
pub fn set_style(&mut self, style: Style)
Sourcepub fn key_filter(
self,
key_filter: impl 'static + Fn(&Key, &Modifiers) -> bool,
) -> Self
pub fn key_filter( self, key_filter: impl 'static + Fn(&Key, &Modifiers) -> bool, ) -> Self
Allows you to add a filter to stop the terminal from capturing keypresses you want to use for your application.
If the given filter returns true, the keypress will be ignored.
pub fn set_key_filter( &mut self, key_filter: impl 'static + Fn(&Key, &Modifiers) -> bool, )
pub fn focus<T>(&self) -> Task<T>where
T: Send + 'static,
pub fn focus_with_id<T>(id: impl Into<Id>) -> Task<T>where
T: Send + 'static,
pub fn get_title(&self) -> &str
pub fn advance_bytes<B>(&mut self, bytes: B)
pub fn update(&mut self, message: Message) -> Action
pub fn view<'a, Theme, Renderer>( &'a self, ) -> Element<'a, Message, Theme, Renderer>